==> zhongyan-manage-service-api-3.0.16-20221214.014921-3-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/export/ExportMonthPlanData.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report.export;

import com.alibaba.excel.annotation.ExcelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * @author zht
 * @Date 2022/9/19
 */
@Data
public class ExportMonthPlanData  implements Serializable {

    /**
     * 日期
     */
    @ExcelProperty("活动时间")
    private String activityTime;


    @ExcelProperty("活动名称")
    private String activityName;


    @ExcelProperty("活动品规")
    private String regulateList;

    /**
     * 活动版块
     */
    @ExcelProperty("活动板块")
    private String templateName;


    @ExcelProperty({"审批单","发布审批","活动方案"})
    private String releaseApproval;

    @ExcelProperty({"审批单","发布审批","物资审批"})
    private String materialApproval;

    @ExcelProperty({"审批单","发布审批","活动开发"})
    private String eventDevelopment;

    @ExcelProperty({"审批单","发布审批","推文"})
    private String tweets;

    @ExcelProperty({"审批单","发布审批","活动发布"})
    private String eventRelease;

    @ExcelProperty({"审批单","发布审批","直播"})
    private String liveStreaming;


    @ExcelProperty({"审批单","发布审批","模板消息"})
    private String templateMessage;

    @ExcelProperty({"代办事项","活动筹备","实现路径设计"})
    private String implementPathDesign;

    @ExcelProperty({"代办事项","活动筹备","视觉设计"})
    private String visualDesign;

    @ExcelProperty({"代办事项","活动筹备","活动开发"})
    private String eventDevelopmentLast;

    @ExcelProperty({"代办事项","活动筹备","即期保障"})
    private String immediateProtection;


    @ExcelProperty({"代办事项","奖品筹备","烟(包/条）"})
    private String smoke;

    @ExcelProperty({"代办事项","奖品筹备","第三方奖品"})
    private String thirdPartyPrizes;

    @ExcelProperty({"代办事项","宣传物料","海报设计"})
    private String posterDesign;


    @ExcelProperty({"代办事项","宣传物料","竖牌设计"})
    private String verticalDesign;


    @ExcelProperty({"代办事项","宣传物料","折页设计"})
    private String foldingDesign;
    @ExcelProperty({"代办事项","宣传物料","卡片设计"})
    private String cardDesign;


    @ExcelProperty({"代办事项","宣传物料","推文"})
    private String tweetsLast;


    @ExcelProperty({"代办事项","宣传物料","视频制作"})
    private String videoProduction;


    @ExcelProperty({"代办事项","活动收尾","数据回流"})
    private String dataReflow;

    @ExcelProperty({"代办事项","活动收尾","奖品发放"})
    private String prizeDistribution;

    @ExcelProperty({"代办事项","活动收尾","妥投"})
    private String compromise;
    /**
     * 部门
     */
    @ExcelProperty("部门")
    private String departmentList;
    /**
     * 状态
     */
    @ExcelProperty("状态")
    private String status;
    /**
     * 活动负责人
     */
    @ExcelProperty("负责人")
    private String dutyPersonVoList;




}

==> zhongyan-manage-service-api-3.0.45-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/export/ExportMonthPlanData.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report.export;

import com.alibaba.excel.annotation.ExcelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * @author zht
 * @Date 2022/9/19
 */
@Data
public class ExportMonthPlanData  implements Serializable {

    /**
     * 日期
     */
    @ExcelProperty("活动时间")
    private String activityTime;


    @ExcelProperty("活动描述")
    private String activityName;


    @ExcelProperty("活动品规")
    private String regulateList;

    /**
     * 活动版块
     */
    @ExcelProperty("运营项目")
    private String templateName;


    @ExcelProperty({"审批单","发布审批","活动方案"})
    private String releaseApproval;

    @ExcelProperty({"审批单","发布审批","物资审批"})
    private String materialApproval;

    @ExcelProperty({"审批单","发布审批","活动开发"})
    private String eventDevelopment;

    @ExcelProperty({"审批单","发布审批","推文"})
    private String tweets;

    @ExcelProperty({"审批单","发布审批","活动发布"})
    private String eventRelease;

    @ExcelProperty({"审批单","发布审批","直播"})
    private String liveStreaming;


    @ExcelProperty({"审批单","发布审批","模板消息"})
    private String templateMessage;

    @ExcelProperty({"代办事项","活动筹备","实现路径设计"})
    private String implementPathDesign;

    @ExcelProperty({"代办事项","活动筹备","视觉设计"})
    private String visualDesign;

    @ExcelProperty({"代办事项","活动筹备","活动开发"})
    private String eventDevelopmentLast;

    @ExcelProperty({"代办事项","活动筹备","即期保障"})
    private String immediateProtection;


    @ExcelProperty({"代办事项","奖品筹备","烟(包/条）"})
    private String smoke;

    @ExcelProperty({"代办事项","奖品筹备","第三方奖品"})
    private String thirdPartyPrizes;

    @ExcelProperty({"代办事项","宣传物料","海报设计"})
    private String posterDesign;


    @ExcelProperty({"代办事项","宣传物料","竖牌设计"})
    private String verticalDesign;


    @ExcelProperty({"代办事项","宣传物料","折页设计"})
    private String foldingDesign;
    @ExcelProperty({"代办事项","宣传物料","卡片设计"})
    private String cardDesign;


    @ExcelProperty({"代办事项","宣传物料","推文"})
    private String tweetsLast;


    @ExcelProperty({"代办事项","宣传物料","视频制作"})
    private String videoProduction;


    @ExcelProperty({"代办事项","活动收尾","数据回流"})
    private String dataReflow;

    @ExcelProperty({"代办事项","活动收尾","奖品发放"})
    private String prizeDistribution;

    @ExcelProperty({"代办事项","活动收尾","妥投"})
    private String compromise;
    /**
     * 部门
     */
    @ExcelProperty("部门")
    private String departmentList;
    /**
     * 状态
     */
    @ExcelProperty("状态")
    private String status;
    /**
     * 活动负责人
     */
    @ExcelProperty("负责人")
    private String dutyPersonVoList;




}
